<template>
    <Head title="Major"/>
    <AdminMainLayout>
        <div class="card">
            <div class="card-body">
                <div class="card-header bg-white border-bottom">
                    <div class="row align-items-center">
                        <div class="col-md-4">
                            <h4 class="mb-0 text-primary">
                                Daftar Pelamar: <span class="fw-bold">{{ vacancy.title }}</span>
                            </h4>
                        </div>
                        <div class="col-md-8 d-flex align-items-center justify-content-end gap-3 flex-wrap">
                            <!-- Dropdown Status -->
                            <BaseDropDown
                                :options="status_application.map((status) => ({ label: status, value: status }))"
                                name="status"
                                placeholder="Pilih Status"
                                v-model="selectedStatus"
                                class="w-50"
                            />

                            <!-- Tombol Ubah Status -->
                            <button
                                class="btn btn-primary"
                                @click="submitStatusUpdate"
                                :disabled="!selectedApplicants.length || !selectedStatus"
                            >
                                <i class="bi bi-pencil-square me-1"></i> Ubah Status
                            </button>

                            <!-- Tombol Export -->
                            <div class="btn-group">
                                <a
                                    :href="`/backoffice/admin/vacancy/${vacancy.id}/export-applicant?type=csv`"
                                    class="btn btn-outline-primary"
                                >
                                    <i class="bi bi-filetype-csv"></i> CSV
                                </a>
                                <a
                                    :href="`/backoffice/admin/vacancy/${vacancy.id}/export-applicant?type=xlsx`"
                                    class="btn btn-outline-primary"
                                >
                                    <i class="bi bi-file-earmark-spreadsheet"></i> Excel
                                </a>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="table-responsive">
                    <table class="table table-striped">
                        <thead>
                        <tr>
                            <th>
                                <input type="checkbox" :checked="allSelected" @change="toggleAll">
                            </th>
                            <th>No</th>
                            <th>Nama</th>
                            <th>Email</th>
                            <th>NISN</th>
                            <th>Jurusan</th>
                            <th>Status</th>
                            <th>Tahun Lulus</th>
                        </tr>
                        </thead>
                        <tbody>
                        <tr v-for="(applicant, index) in data.data" :key="applicant.id">
                            <td>
                                <input
                                    type="checkbox"
                                    :value="applicant.id"
                                    :checked="selectedApplicants.includes(applicant.id)"
                                    @change="toggleSelection(applicant.id)"
                                />
                            </td>
                            <td>{{ index + 1 }}</td>
                            <td>{{ applicant.user.name }}</td>
                            <td>{{ applicant.user.email }}</td>
                            <td>{{ applicant.user.nisn }}</td>
                            <td>{{ applicant.user.major.name }}</td>
                            <td>
                                <span class="badge" :class="{
                                    'bg-warning': applicant.status === 'applied',
                                    'bg-info': applicant.status === 'interviewed',
                                    'bg-success': applicant.status === 'hired',
                                    'bg-danger': applicant.status === 'rejected'
                                }">
                                    {{ applicant.status }}
                                </span>
                            </td>
                            <td>{{ applicant.user.graduation_year.year }}</td>
                        </tr>
                        <tr v-if="data.data.length === 0">
                            <td colspan="7" class="text-center">Tidak ada pelamar</td>
                        </tr>
                        </tbody>
                    </table>
                </div>
            </div>
        </div>
    </AdminMainLayout>
</template>

<script setup>
import AdminMainLayout from "@/Layouts/AdminMainLayout.vue";
import { Head, useForm, router } from "@inertiajs/vue3";
import BaseDropDown from "@/Components/Forms/BaseDropDown.vue";
import { computed, ref } from "vue";

const props = defineProps({
    data: {
        type: Object,
        required: true
    },
    vacancy: {
        type: Object,
        required: true
    },
    status_application: {
        type: Array,
        required: true
    }
});

const selectedApplicants = ref([]);
const selectedStatus = ref("");

const allSelected = computed({
    get() {
        return (
            selectedApplicants.value.length === props.data.data.length &&
            props.data.data.length > 0
        );
    },
    set(value) {
        if (value) {
            selectedApplicants.value = props.data.data.map(applicant => applicant.id);
        } else {
            selectedApplicants.value = [];
        }
    }
});

const toggleAll = () => {
    allSelected.value = !allSelected.value;
};

const toggleSelection = (id) => {
    if (selectedApplicants.value.includes(id)) {
        selectedApplicants.value = selectedApplicants.value.filter(applicantId => applicantId !== id);
    } else {
        selectedApplicants.value.push(id);
    }
};

const submitStatusUpdate = () => {
    if (selectedApplicants.value.length && selectedStatus.value) {
        useForm({
            status: selectedStatus.value,
            candidate_applies_ids: selectedApplicants.value
        }).post('/backoffice/admin/vacancy/applicant/change-status-applicant', {
            onSuccess: () => {
                selectedApplicants.value = [];
                selectedStatus.value = "";
            }
        });
    }
};
</script>
